@@ -4,11 +4,10 @@ extensions = [
     "sphinx.ext.extlinks",
 ]
 templates_path = ["_templates"]
-source_suffix = ".rst"
 master_doc = "index"
 
 project = "Alabaster"
-copyright = f"{datetime.now().year} Jeff Forcier"
+copyright = f"{datetime.now().year}, the Sphinx developers"
 
 exclude_patterns = ["_build"]
 
@@ -23,9 +22,9 @@ html_theme = "alabaster"
 html_sidebars = {
     "**": [
         "about.html",
+        "searchfield.html",
         "navigation.html",
         "relations.html",
-        "searchbox.html",
         "donate.html",
     ]
 }
@@ -35,4 +34,5 @@ html_theme_options = {
     "github_repo": "alabaster",
     "fixed_sidebar": True,
     "tidelift_url": "https://tidelift.com/subscription/pkg/pypi-alabaster?utm_source=pypi-alabaster&utm_medium=referral&utm_campaign=docs",  # noqa
+    "github_banner": True,
 }
